==> u++_5.0.1.orig.tar.gz: u++-5.0.1/src/scheduler/uLifoScheduler.cc <==
//                              -*- Mode: C++ -*- 
// 
// uC++ Version 5.0.1, Copyright (C) Jiongxiong Chen and Ashif S. Harji 2003
// 
// uLifoScheduler.h -- 
// 
// Author           : Jiongxiong Chen and Ashif S. Harji
// Created On       : Fri Feb 14 14:26:49 2003
// Last Modified By : Peter A. Buhr
// Last Modified On : Mon Dec  8 21:35:00 2003
// Update Count     : 135
//
// This  library is free  software; you  can redistribute  it and/or  modify it
// under the terms of the GNU Lesser General Public License as published by the
// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
// option) any later version.
// 
// This library is distributed in the  hope that it will be useful, but WITHOUT
// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
// for more details.
// 
// You should  have received a  copy of the  GNU Lesser General  Public License
// along  with this library.
// 

#define __U_KERNEL__
#include <uC++.h>
#include <uLifoScheduler.h>


//#include <uDebug.h>

bool uLifoScheduler::uEmpty() const {
    return list.uEmpty();
} // uLifoScheduler::uEmpty

void uLifoScheduler::uAdd( uBaseTaskDL *node ) {
    list.uAddTail( node );
} // uLifoScheduler::uAdd

uBaseTaskDL *uLifoScheduler::uDrop() {
    uBaseTaskDL *temp = list.uDropTail();
    return temp;
} // uLifoScheduler::uDrop

bool uLifoScheduler::uCheckPriority( uBaseTaskDL &, uBaseTaskDL & ) { return false; }

void uLifoScheduler::uResetPriority( uBaseTaskDL &, uBaseTaskDL & ) {}

void uLifoScheduler::uAddInitialize( uBaseTaskSeq & ) {};

void uLifoScheduler::uRemoveInitialize( uBaseTaskSeq & ) {};

void uLifoScheduler::uRescheduleTask( uBaseTaskDL *, uBaseTaskSeq & ) {};


// Local Variables: //
// compile-command: "gmake install" //
// End: //

==> u++_5.3.0.orig.tar.gz: u++-5.3.0/src/scheduler/uLifoScheduler.cc <==
//                              -*- Mode: C++ -*- 
// 
// uC++ Version 5.3.0, Copyright (C) Jiongxiong Chen and Ashif S. Harji 2003
// 
// uLifoScheduler.h -- 
// 
// Author           : Jiongxiong Chen and Ashif S. Harji
// Created On       : Fri Feb 14 14:26:49 2003
// Last Modified By : Peter A. Buhr
// Last Modified On : Mon Oct 10 11:18:18 2005
// Update Count     : 143
//
// This  library is free  software; you  can redistribute  it and/or  modify it
// under the terms of the GNU Lesser General Public License as published by the
// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
// option) any later version.
// 
// This library is distributed in the  hope that it will be useful, but WITHOUT
// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
// for more details.
// 
// You should  have received a  copy of the  GNU Lesser General  Public License
// along  with this library.
// 

#define __U_KERNEL__
#include <uC++.h>
#include <uLifoScheduler.h>


//#include <uDebug.h>

bool uLifoScheduler::empty() const {
    return list.empty();
} // uLifoScheduler::empty

void uLifoScheduler::add( uBaseTaskDL *node ) {
    list.addTail( node );
} // uLifoScheduler::add

uBaseTaskDL *uLifoScheduler::drop() {
    uBaseTaskDL *temp = list.dropTail();
    return temp;
} // uLifoScheduler::drop

bool uLifoScheduler::uCheckPriority( uBaseTaskDL &, uBaseTaskDL & ) { return false; }

void uLifoScheduler::uResetPriority( uBaseTaskDL &, uBaseTaskDL & ) {}

void uLifoScheduler::addInitialize( uBaseTaskSeq & ) {};

void uLifoScheduler::removeInitialize( uBaseTaskSeq & ) {};

void uLifoScheduler::uRescheduleTask( uBaseTaskDL *, uBaseTaskSeq & ) {};


// Local Variables: //
// compile-command: "gmake install" //
// End: //
